@@ -180,7 +180,7 @@ AaModification::createInstance(const QString &accession)
       term.m_name        = "Nter hydrolytic cleavage H+";
       return (AaModification::createInstance(term));
     }
-  if(accession == "internal:Cter_hydrolytic_cleavage_HO")
+  else if(accession == "internal:Cter_hydrolytic_cleavage_HO")
     {
       OboPsiModTerm term;
       term.setAccession(accession);
@@ -189,7 +189,20 @@ AaModification::createInstance(const QString &accession)
       term.m_name        = "Cter hydrolytic cleavage HO";
       return (AaModification::createInstance(term));
     }
-  if(accession.startsWith("MUTATION:"))
+  else if(accession == "USER:2-Ethynylbenzaldehyde")
+    {
+      //https://pubchem.ncbi.nlm.nih.gov/compound/640368
+      OboPsiModTerm term;
+      term.setAccession(accession);
+      term.m_diffFormula = "H 4 C 9 O 0";//C9H6O
+      term.m_name        = "2-Ethynylbenzaldehyde";
+      ChemicalFormula formula;
+      formula.setOboPsiModTerm(term);
+      term.m_diffMono    = formula.getMass();
+      
+      return (AaModification::createInstance(term));
+    }
+  else if(accession.startsWith("MUTATION:"))
     {
       QRegularExpression regexp_mutation("^MUTATION:([A-Z])=>([A-Z])$");
       QRegularExpressionMatch match = regexp_mutation.match(accession);
@@ -204,7 +217,7 @@ AaModification::createInstance(const QString &accession)
           // m_psiModLabel<<"|";
         }
     }
-  if(accession.startsWith("C13N15:"))
+  else if(accession.startsWith("C13N15:"))
     {
       QRegularExpression regexp_label("^C13N15:([A-Z])$");
       QRegularExpressionMatch match = regexp_label.match(accession);
@@ -268,8 +281,9 @@ AaModification::setXrefOrigin(const QString &origin)
 void
 AaModification::calculateMassFromChemicalComponents()
 {
-  pappso_double theoreticalm_mass                          = 0;
-  std::map<Enums::AtomIsotopeSurvey, int>::const_iterator it_atom = m_atomCount.find(Enums::AtomIsotopeSurvey::C);
+  pappso_double theoreticalm_mass = 0;
+  std::map<Enums::AtomIsotopeSurvey, int>::const_iterator it_atom =
+    m_atomCount.find(Enums::AtomIsotopeSurvey::C);
   if(it_atom != m_atomCount.end())
     {
       theoreticalm_mass += MASSCARBON * (it_atom->second);
@@ -947,21 +961,27 @@ AaModification::createInstanceC13N15LabelledAminoAcid(const QChar &from_aa)
 void
 pappso::AaModification::setDiffFormula(const pappso::ChemicalFormula &diff_formula)
 {
-  m_atomCount[Enums::AtomIsotopeSurvey::C] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::C);
-  m_atomCount[Enums::AtomIsotopeSurvey::H] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::H);
-  m_atomCount[Enums::AtomIsotopeSurvey::N] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::N);
-  m_atomCount[Enums::AtomIsotopeSurvey::O] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::O);
-  m_atomCount[Enums::AtomIsotopeSurvey::S] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::S);
-  m_atomCount[Enums::AtomIsotopeSurvey::P] = diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::P);
+  m_atomCount[Enums::AtomIsotopeSurvey::C] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::C);
+  m_atomCount[Enums::AtomIsotopeSurvey::H] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::H);
+  m_atomCount[Enums::AtomIsotopeSurvey::N] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::N);
+  m_atomCount[Enums::AtomIsotopeSurvey::O] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::O);
+  m_atomCount[Enums::AtomIsotopeSurvey::S] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::S);
+  m_atomCount[Enums::AtomIsotopeSurvey::P] =
+    diff_formula.getNumberOfAtom(Enums::AtomIsotopeSurvey::P);
 
   for(Enums::Isotope isotope : {Enums::Isotope::C13,
-                                 Enums::Isotope::H2,
-                                 Enums::Isotope::N15,
-                                 Enums::Isotope::O17,
-                                 Enums::Isotope::O18,
-                                 Enums::Isotope::S33,
-                                 Enums::Isotope::S34,
-                                 Enums::Isotope::S36})
+                                Enums::Isotope::H2,
+                                Enums::Isotope::N15,
+                                Enums::Isotope::O17,
+                                Enums::Isotope::O18,
+                                Enums::Isotope::S33,
+                                Enums::Isotope::S34,
+                                Enums::Isotope::S36})
     {
       m_mapIsotope.at(isotope) = diff_formula.getNumberOfIsotope(isotope);
     }
