@@ -49,6 +49,12 @@ CborStreamWriter::~CborStreamWriter()
 }
 
 
+const QString &
+CborStreamWriter::getUuid() const
+{
+  return m_uuid;
+}
+
 void
 CborStreamWriter::writeInformations(const QString &software_name,
                                     const QString &software_version,
@@ -75,9 +81,10 @@ CborStreamWriter::writeInformations(const QString &software_name,
   append(QSysInfo::prettyProductName());
   append(QLatin1String("timestamp"));
   append(QDateTime::currentDateTime().toString(Qt::ISODate));
-  
+
   append(QLatin1String("uuid"));
-  append(QUuid::createUuid().toString());
+  m_uuid = QUuid::createUuid().toString();
+  append(m_uuid);
   endMap();
 }
 
@@ -116,8 +123,21 @@ CborStreamWriter::writeArray(const std::vector<int> &positions)
   endArray();
 }
 
+
 void
-CborStreamWriter::writeArray(QStringList &str_list)
+CborStreamWriter::writeArray(const std::vector<qint64> &int_list)
+{
+
+  startArray(int_list.size());
+  for(auto num : int_list)
+    {
+      append(num);
+    }
+  endArray();
+}
+
+void
+CborStreamWriter::writeArray(const QStringList &str_list)
 {
   startArray(str_list.size());
   for(auto str_item : str_list)
@@ -127,6 +147,16 @@ CborStreamWriter::writeArray(QStringList &str_list)
   endArray();
 }
 
+void
+CborStreamWriter::writeArray(const std::vector<QString> &str_list)
+{
+  startArray(str_list.size());
+  for(auto str_item : str_list)
+    {
+      append(str_item);
+    }
+  endArray();
+}
 
 void
 CborStreamWriter::writeCborMap(const QCborMap &cbor_map)
