@@ -26,6 +26,7 @@
  ******************************************************************************/
 #pragma once
 
+#include "pappsomspp/export-import-config.h"
 #include "pappsomspp/core/processing/cbor/cborstreamreaderinterface.h"
 #include "pappsomspp/core/processing/uimonitor/uimonitorinterface.h"
 #include "psmproteinmap.h"
@@ -51,7 +52,7 @@ struct PsmFile
 /**
  * @todo write docs
  */
-class PsmFileReaderBase : public CborStreamReaderInterface
+class PMSPP_LIB_DECL PsmFileReaderBase : public CborStreamReaderInterface
 {
   public:
   /**
@@ -62,8 +63,9 @@ class PsmFileReaderBase : public CborStreamReaderInterface
   /**
    * Destructor
    */
-  virtual ~PsmFileReaderBase();
+  virtual ~PsmFileReaderBase() override;
   void readCbor(QFile *cborp, pappso::UiMonitorInterface &monitor);
+  void readCbor(QIODevice *cborp, pappso::UiMonitorInterface &monitor);
 
   struct PsmProteinRef
   {
@@ -71,8 +73,6 @@ class PsmFileReaderBase : public CborStreamReaderInterface
     std::vector<std::size_t> positions;
   };
 
-  virtual void close();
-
   protected:
   void readRoot(pappso::UiMonitorInterface &monitor);
   virtual void readInformations(pappso::UiMonitorInterface &monitor);
