@@ -27,6 +27,7 @@
  ******************************************************************************/
 
 #pragma once
+#include "pappsomspp/export-import-config.h"
 #include "pappsomspp/core/fasta/fastahandlerinterface.h"
 #include "pappsomspp/core/processing/uimonitor/uimonitorinterface.h"
 #include <QJsonDocument>
@@ -43,7 +44,7 @@ namespace psm
 /**
  * @todo write docs
  */
-class SageFileReader
+class PMSPP_LIB_DECL SageFileReader
 {
   public:
   /**
