@@ -46,7 +46,6 @@ namespace psm
 
 SageTsvHandler::SageTsvHandler(pappso::UiMonitorInterface *p_monitor,
                                const SageReader &sage_reader,
-                               bool is_fasta_pass,
                                PsmProteinMap &psm_protein_map)
   : m_sageReader(sage_reader), m_psmProteinMap(psm_protein_map)
 {
@@ -54,7 +53,6 @@ SageTsvHandler::SageTsvHandler(pappso::UiMonitorInterface *p_monitor,
   m_staticModificationList   = sage_reader.getStaticModificationList();
   m_variableModificationList = sage_reader.getVariableModificationList();
   m_decoyTag                 = sage_reader.getDecoyTag();
-  m_isFirstPass              = is_fasta_pass;
 }
 
 SageTsvHandler::~SageTsvHandler()
@@ -62,7 +60,7 @@ SageTsvHandler::~SageTsvHandler()
 }
 
 void
-SageTsvHandler::endDocument()
+SageTsvHandler::writeSampleList()
 {
   for(auto it_sample_map : m_sampleMap)
     {
@@ -422,7 +420,11 @@ SageTsvHandler::startLine()
 }
 
 void
-SageTsvHandler::startSheet(const QString &sheet_name)
+SageTsvHandler::endDocument()
+{
+}
+void
+SageTsvHandler::startSheet(const QString &sheet_name [[maybe_unused]])
 {
   m_columnNumber = 0;
   m_lineNumber   = 0;
@@ -438,8 +440,6 @@ void
 SageTsvHandler::parsePeptide(const QString &peptide_str)
 {
   qDebug();
-  if(m_isFirstPass)
-    return;
   QString peptide_str_verif = peptide_str;
   // fixed modifications :
   for(SageReader::SageModification modif : m_staticModificationList)
@@ -476,21 +476,18 @@ SageTsvHandler::parseProteins(const QString &proteins_str)
 {
   m_proteinList.clear();
   m_proteinList = proteins_str.split(";");
-  if(m_isFirstPass)
+  for(QString accession : m_proteinList)
     {
-      for(QString accession : m_proteinList)
+
+      PsmProtein psm_protein;
+      psm_protein.protein_sp = std::make_shared<pappso::Protein>(accession, "");
+      psm_protein.isTarget   = true;
+      if(accession.startsWith(m_decoyTag))
         {
-
-          PsmProtein psm_protein;
-          psm_protein.protein_sp = std::make_shared<pappso::Protein>(accession, "");
-          psm_protein.isTarget   = true;
-          if(accession.startsWith(m_decoyTag))
-            {
-              psm_protein.isTarget = false;
-            }
-
-          m_psmProteinMap.insert(psm_protein);
+          psm_protein.isTarget = false;
         }
+
+      m_psmProteinMap.insert(psm_protein);
     }
 }
 
@@ -499,8 +496,6 @@ SageTsvHandler::parseSpectrumStringId(const QString &spectrum_string_id)
 {
   m_spectrumNativeId = spectrum_string_id;
   qDebug() << spectrum_string_id;
-  if(m_isFirstPass)
-    return false;
   // controllerType=0 controllerNumber=1 scan=176056
 
   bool is_ok            = false;
@@ -541,8 +536,6 @@ void
 SageTsvHandler::parseMsRunFilename(const QString &msrun_filename)
 {
 
-  if(m_isFirstPass)
-    return;
 
   // find the sample :
   auto it_insert   = m_sampleMap.insert({msrun_filename, {}});
@@ -565,7 +558,7 @@ SageTsvHandler::parseMsRunFilename(const QString &msrun_filename)
                                                       identification_file_list);
 
 
-      ms_file.insert(QString("name"), QFileInfo(msrun_filename).absoluteFilePath());
+      ms_file.insert(QString("name"), m_sageReader.getMzmlPath(msrun_filename));
       it_insert.first->second.cbor_core_sample.insert(QString("peaklist_file"), ms_file);
     }
 
@@ -587,125 +580,98 @@ SageTsvHandler::recordLine()
 {
   qDebug();
 
-  if(m_isFirstPass)
+  for(const QString &accession : m_proteinList)
     {
-      for(const QString &accession : m_proteinList)
-        {
-          PsmProtein psm_protein;
-          psm_protein.protein_sp = std::make_shared<pappso::Protein>(accession, "");
+      PsmProtein psm_protein;
+      psm_protein.protein_sp = std::make_shared<pappso::Protein>(accession, "");
 
-          auto it = m_psmProteinMap.insert(psm_protein);
-          it.first->second.cborEval.insert(QString("protein_q"), m_line.protein_q);
-        }
+      auto it = m_psmProteinMap.insert(psm_protein);
+      it.first->second.cborEval.insert(QString("protein_q"), m_line.protein_q);
     }
-  else
+  /*
+  PeptideEvidence pe(msp_msrun.get(), m_spectrumIndex, true);
+  pe.setCharge(m_line.charge);
+  pe.setChecked(true);
+  pe.setExperimentalMass(m_line.expmass);
+  pe.setPeptideXtpSp(msp_peptide);
+  pe.setIdentificationDataSource(msp_identificationSageJsonFileSp.get());
+  pe.setIdentificationEngine(m_identificationEngine);
+  pe.setRetentionTime(m_line.rt);
+  pe.setParam(PeptideEvidenceParam::tandem_hyperscore, m_line.hyperscore);
+  pe.setParam(PeptideEvidenceParam::sage_sage_discriminant_score,
+              m_line.sage_discriminant_score);
+  pe.setParam(PeptideEvidenceParam::sage_peptide_q, m_line.peptide_q);
+  pe.setParam(PeptideEvidenceParam::sage_posterior_error, m_line.posterior_error);
+  pe.setParam(PeptideEvidenceParam::sage_spectrum_q, m_line.spectrum_q);
+  pe.setParam(PeptideEvidenceParam::sage_predicted_rt, m_line.predicted_rt);
+  pe.setParam(PeptideEvidenceParam::sage_isotope_error, m_line.isotope_error);
+
+
+  PeptideMatch peptide_match;
+  // peptide_match.setStart(mz_peptide_evidence.start);
+  peptide_match.setPeptideEvidenceSp(
+    msp_identificationSageJsonFileSp.get()->getPeptideEvidenceStore().getInstance(&pe));
+    */
+
+  // find the scan in sample
+  auto it_insert            = mp_currentSample->scan_map.insert({m_spectrumNativeId, Scan()});
+  Scan *current_cbor_scan_p = &(it_insert.first->second);
+  if(it_insert.second)
     {
-      /*
-      PeptideEvidence pe(msp_msrun.get(), m_spectrumIndex, true);
-      pe.setCharge(m_line.charge);
-      pe.setChecked(true);
-      pe.setExperimentalMass(m_line.expmass);
-      pe.setPeptideXtpSp(msp_peptide);
-      pe.setIdentificationDataSource(msp_identificationSageJsonFileSp.get());
-      pe.setIdentificationEngine(m_identificationEngine);
-      pe.setRetentionTime(m_line.rt);
-      pe.setParam(PeptideEvidenceParam::tandem_hyperscore, m_line.hyperscore);
-      pe.setParam(PeptideEvidenceParam::sage_sage_discriminant_score,
-                  m_line.sage_discriminant_score);
-      pe.setParam(PeptideEvidenceParam::sage_peptide_q, m_line.peptide_q);
-      pe.setParam(PeptideEvidenceParam::sage_posterior_error, m_line.posterior_error);
-      pe.setParam(PeptideEvidenceParam::sage_spectrum_q, m_line.spectrum_q);
-      pe.setParam(PeptideEvidenceParam::sage_predicted_rt, m_line.predicted_rt);
-      pe.setParam(PeptideEvidenceParam::sage_isotope_error, m_line.isotope_error);
+      // new scan
+      QCborMap &scan_id = it_insert.first->second.cbor_id;
+      scan_id.insert(QString("index"), (qint64)m_spectrumIndex);
+      scan_id.insert(QString("native_id"), m_spectrumNativeId);
 
+      QCborMap &scan_ms2 = it_insert.first->second.cbor_ms2;
+      scan_ms2.insert(QString("rt"), m_line.rt);
 
-      PeptideMatch peptide_match;
-      // peptide_match.setStart(mz_peptide_evidence.start);
-      peptide_match.setPeptideEvidenceSp(
-        msp_identificationSageJsonFileSp.get()->getPeptideEvidenceStore().getInstance(&pe));
-        */
-
-      // find the scan in sample
-      auto it_insert            = mp_currentSample->scan_map.insert({m_spectrumNativeId, Scan()});
-      Scan *current_cbor_scan_p = &(it_insert.first->second);
-      if(it_insert.second)
-        {
-          // new scan
-          QCborMap &scan_id = it_insert.first->second.cbor_id;
-          scan_id.insert(QString("index"), (qint64)m_spectrumIndex);
-          scan_id.insert(QString("native_id"), m_spectrumNativeId);
-
-          QCborMap &scan_ms2 = it_insert.first->second.cbor_ms2;
-          scan_ms2.insert(QString("rt"), m_line.rt);
-
-          QCborMap &scan_precursor = it_insert.first->second.cbor_precursor;
-          scan_precursor.insert(QString("z"), m_line.charge);
-          scan_precursor.insert(QString("mz"), m_line.expmass);
-        }
-
-      Psm one_psm;
-      one_psm.proforma = msp_peptide.get()->toProForma();
-
-      for(const QString &accession : m_proteinList)
-        {
-          QCborMap cbor_protein;
-          cbor_protein.insert(QString("accession"), accession);
-
-
-          // start/end positions
-          QString protein_sequence =
-            QString(m_psmProteinMap.getByAccession(accession).protein_sp.get()->getSequence())
-              .replace("L", "I");
-          QString peptide_sequence = msp_peptide.get()->getSequenceLi();
-          int position             = protein_sequence.indexOf(peptide_sequence);
-
-          QCborArray positions;
-          while(position >= 0)
-            {
-              positions.push_back(position);
-              position = protein_sequence.indexOf(peptide_sequence, position + 1);
-            }
-
-          cbor_protein.insert(QString("positions"), positions);
-
-          one_psm.cbor_protein_list.append(cbor_protein);
-        }
-
-      one_psm.cbor_eval.insert(QString("aligned_rt"), m_line.aligned_rt);
-      one_psm.cbor_eval.insert(QString("calcmass"), m_line.calcmass);
-      one_psm.cbor_eval.insert(QString("delta_best"), m_line.delta_best);
-      one_psm.cbor_eval.insert(QString("delta_mobility"), m_line.delta_mobility);
-      one_psm.cbor_eval.insert(QString("delta_next"), m_line.delta_next);
-      one_psm.cbor_eval.insert(QString("delta_rt_model"), m_line.delta_rt_model);
-      one_psm.cbor_eval.insert(QString("fragment_ppm"), m_line.fragment_ppm);
-      one_psm.cbor_eval.insert(QString("hyperscore"), m_line.hyperscore);
-      one_psm.cbor_eval.insert(QString("ion_mobility"), m_line.ion_mobility);
-      one_psm.cbor_eval.insert(QString("isotope_error"), m_line.isotope_error);
-      one_psm.cbor_eval.insert(QString("label"), m_line.label);
-      one_psm.cbor_eval.insert(QString("longest_b"), (qint64)m_line.longest_b);
-      one_psm.cbor_eval.insert(QString("longest_y"), (qint64)m_line.longest_y);
-      one_psm.cbor_eval.insert(QString("longest_y_pct"), m_line.longest_y_pct);
-      one_psm.cbor_eval.insert(QString("matched_intensity_pct"), m_line.matched_intensity_pct);
-      one_psm.cbor_eval.insert(QString("matched_peaks"), (qint64)m_line.matched_peaks);
-      one_psm.cbor_eval.insert(QString("missed_cleavages"), m_line.missed_cleavages);
-      one_psm.cbor_eval.insert(QString("ms2_intensity"), m_line.ms2_intensity);
-      one_psm.cbor_eval.insert(QString("peptide_len"), (qint64)m_line.peptide_len);
-      one_psm.cbor_eval.insert(QString("peptide_q"), m_line.peptide_q);
-      one_psm.cbor_eval.insert(QString("poisson"), m_line.poisson);
-      one_psm.cbor_eval.insert(QString("posterior_error"), m_line.posterior_error);
-      one_psm.cbor_eval.insert(QString("precursor_ppm"), m_line.precursor_ppm);
-      one_psm.cbor_eval.insert(QString("predicted_mobility"), m_line.predicted_mobility);
-      one_psm.cbor_eval.insert(QString("predicted_rt"), m_line.predicted_rt);
-      one_psm.cbor_eval.insert(QString("protein_q"), m_line.protein_q);
-      one_psm.cbor_eval.insert(QString("rank"), m_line.rank);
-      one_psm.cbor_eval.insert(QString("sage_discriminant_score"), m_line.sage_discriminant_score);
-      one_psm.cbor_eval.insert(QString("scored_candidates"), (qint64)m_line.scored_candidates);
-      one_psm.cbor_eval.insert(QString("semi_enzymatic"), m_line.semi_enzymatic);
-      one_psm.cbor_eval.insert(QString("spectrum_q"), m_line.spectrum_q);
-
-      current_cbor_scan_p->psm_list.emplace_back(one_psm);
+      QCborMap &scan_precursor = it_insert.first->second.cbor_precursor;
+      scan_precursor.insert(QString("z"), m_line.charge);
+      scan_precursor.insert(QString("mz"), m_line.expmass);
     }
 
+  Psm one_psm;
+  one_psm.peptide_sequence_li = msp_peptide.get()->getSequenceLi();
+  one_psm.proforma            = msp_peptide.get()->toProForma();
+  one_psm.protein_list        = m_proteinList;
+
+
+  one_psm.cbor_eval.insert(QString("aligned_rt"), m_line.aligned_rt);
+  one_psm.cbor_eval.insert(QString("calcmass"), m_line.calcmass);
+  one_psm.cbor_eval.insert(QString("delta_best"), m_line.delta_best);
+  one_psm.cbor_eval.insert(QString("delta_mobility"), m_line.delta_mobility);
+  one_psm.cbor_eval.insert(QString("delta_next"), m_line.delta_next);
+  one_psm.cbor_eval.insert(QString("delta_rt_model"), m_line.delta_rt_model);
+  one_psm.cbor_eval.insert(QString("fragment_ppm"), m_line.fragment_ppm);
+  one_psm.cbor_eval.insert(QString("hyperscore"), m_line.hyperscore);
+  one_psm.cbor_eval.insert(QString("ion_mobility"), m_line.ion_mobility);
+  one_psm.cbor_eval.insert(QString("isotope_error"), m_line.isotope_error);
+  one_psm.cbor_eval.insert(QString("label"), m_line.label);
+  one_psm.cbor_eval.insert(QString("longest_b"), (qint64)m_line.longest_b);
+  one_psm.cbor_eval.insert(QString("longest_y"), (qint64)m_line.longest_y);
+  one_psm.cbor_eval.insert(QString("longest_y_pct"), m_line.longest_y_pct);
+  one_psm.cbor_eval.insert(QString("matched_intensity_pct"), m_line.matched_intensity_pct);
+  one_psm.cbor_eval.insert(QString("matched_peaks"), (qint64)m_line.matched_peaks);
+  one_psm.cbor_eval.insert(QString("missed_cleavages"), m_line.missed_cleavages);
+  one_psm.cbor_eval.insert(QString("ms2_intensity"), m_line.ms2_intensity);
+  one_psm.cbor_eval.insert(QString("peptide_len"), (qint64)m_line.peptide_len);
+  one_psm.cbor_eval.insert(QString("peptide_q"), m_line.peptide_q);
+  one_psm.cbor_eval.insert(QString("poisson"), m_line.poisson);
+  one_psm.cbor_eval.insert(QString("posterior_error"), m_line.posterior_error);
+  one_psm.cbor_eval.insert(QString("precursor_ppm"), m_line.precursor_ppm);
+  one_psm.cbor_eval.insert(QString("predicted_mobility"), m_line.predicted_mobility);
+  one_psm.cbor_eval.insert(QString("predicted_rt"), m_line.predicted_rt);
+  one_psm.cbor_eval.insert(QString("protein_q"), m_line.protein_q);
+  one_psm.cbor_eval.insert(QString("rank"), m_line.rank);
+  one_psm.cbor_eval.insert(QString("sage_discriminant_score"), m_line.sage_discriminant_score);
+  one_psm.cbor_eval.insert(QString("scored_candidates"), (qint64)m_line.scored_candidates);
+  one_psm.cbor_eval.insert(QString("semi_enzymatic"), m_line.semi_enzymatic);
+  one_psm.cbor_eval.insert(QString("spectrum_q"), m_line.spectrum_q);
+
+  current_cbor_scan_p->psm_list.emplace_back(one_psm);
+
+
   std::size_t progress = m_lineNumber / 10000;
   if(progress > m_progressIndex)
     {
@@ -776,7 +742,35 @@ SageTsvHandler::writePsm(const SageTsvHandler::Psm &one_psm)
   m_sageReader.getCborStreamWriter().append("proforma");
   m_sageReader.getCborStreamWriter().append(one_psm.proforma);
   m_sageReader.getCborStreamWriter().append("protein_list");
-  QCborValue(one_psm.cbor_protein_list).toCbor(m_sageReader.getCborStreamWriter());
+
+  QCborArray cbor_protein_list;
+  for(const QString &accession : one_psm.protein_list)
+    {
+      //qWarning() << "accession=" << accession;
+      QCborMap cbor_protein;
+      cbor_protein.insert(QString("accession"), accession);
+
+
+      // start/end positions
+      QString protein_sequence =
+        QString(m_psmProteinMap.getByAccession(accession).protein_sp.get()->getSequence())
+          .replace("L", "I");
+      int position = protein_sequence.indexOf(one_psm.peptide_sequence_li);
+
+      QCborArray positions;
+      while(position >= 0)
+        {
+          positions.push_back(position);
+          position = protein_sequence.indexOf(one_psm.peptide_sequence_li, position + 1);
+        }
+
+      cbor_protein.insert(QString("positions"), positions);
+
+      cbor_protein_list.append(cbor_protein);
+    }
+
+
+  QCborValue(cbor_protein_list).toCbor(m_sageReader.getCborStreamWriter());
 
   m_sageReader.getCborStreamWriter().append("eval");
   m_sageReader.getCborStreamWriter().startMap();
