@@ -118,10 +118,10 @@ pappso::specpeptidoms::LocationSaver::addLocation(std::size_t beginning,
             m_locations_heap.begin(), m_locations_heap.end(), LocationSaver::locationCompare);
         }
     }
-  catch(const std::exception &stderr)
+  catch(const std::exception &error)
     {
       throw pappso::PappsoException(
-        QObject::tr("addLocation failed std::exception :\n%1").arg(stderr.what()));
+        QObject::tr("addLocation failed std::exception :\n%1").arg(error.what()));
     }
 }
 
