@@ -123,7 +123,7 @@ pappso::specpeptidoms::SpOMSSpectrum::~SpOMSSpectrum()
 void
 pappso::specpeptidoms::SpOMSSpectrum::preprocessSpectrum()
 {
-  bool found;
+  //bool found;
   uint8_t aa;
   std::vector<double>::iterator iter1, iter2;
   std::size_t peak1, peak2, next_l_peak;
