@@ -41,19 +41,16 @@
 
 
 int massSpecTracePlotContextMetaTypeId =
-  qRegisterMetaType<pappso::MassSpecTracePlotContext>(
-    "pappso::MassSpecTracePlotContext");
+  qRegisterMetaType<pappso::MassSpecTracePlotContext>("pappso::MassSpecTracePlotContext");
 
 int massSpecTracePlotContextPtrMetaTypeId =
-  qRegisterMetaType<pappso::MassSpecTracePlotContext *>(
-    "pappso::MassSpecTracePlotContext *");
+  qRegisterMetaType<pappso::MassSpecTracePlotContext *>("pappso::MassSpecTracePlotContext *");
 
 
 namespace pappso
 {
 
-MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent)
-  : BaseTracePlotWidget(parent)
+MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent) : BaseTracePlotWidget(parent)
 {
   BasePlotWidget::m_context.m_dataKind = Enums::DataKind::mz;
   m_context.m_dataKind                 = Enums::DataKind::mz;
@@ -101,11 +98,11 @@ MassSpecTracePlotWidget::keyPressEvent(QKeyEvent *event)
 void
 MassSpecTracePlotWidget::keyReleaseEvent(QKeyEvent *event)
 {
- // Before working on the various data belonging to the base context, we need
- // to get it from the base class and refresh our local context with it.
- refreshBaseContext();
+  // Before working on the various data belonging to the base context, we need
+  // to get it from the base class and refresh our local context with it.
+  refreshBaseContext();
 
- BasePlotWidget::keyReleaseEvent(event);
+  BasePlotWidget::keyReleaseEvent(event);
 }
 
 
@@ -125,9 +122,9 @@ MassSpecTracePlotWidget::keyReleaseEvent(QKeyEvent *event)
 void
 MassSpecTracePlotWidget::mouseMoveHandler(QMouseEvent *event)
 {
- // Before working on the various data belonging to the base context, we need
- // to get it from the base class and refresh our local context with it.
- refreshBaseContext();
+  // Before working on the various data belonging to the base context, we need
+  // to get it from the base class and refresh our local context with it.
+  refreshBaseContext();
 
   BasePlotWidget::mouseMoveHandler(event);
 }
@@ -136,11 +133,13 @@ MassSpecTracePlotWidget::mouseMoveHandler(QMouseEvent *event)
 void
 MassSpecTracePlotWidget::mouseMoveHandlerNotDraggingCursor()
 {
-   // Before working on the various data belonging to the base context, we need
+  // Before working on the various data belonging to the base context, we need
   // to get it from the base class and refresh our local context with it.
   refreshBaseContext();
 
   BasePlotWidget::mouseMoveHandlerNotDraggingCursor();
+
+  // qDebug() << "The current m_lastZ value:" << m_context.m_lastZ;
 }
 
 
@@ -158,8 +157,9 @@ MassSpecTracePlotWidget::mouseMoveHandlerDraggingCursor()
       if(!m_context.m_isMeasuringDistance)
         return;
 
-      // qDebug() << "lastMovingMouseButtons:"
-      //<< m_context.m_baseContext.m_lastMovingMouseButtons;
+      // qDebug() << "Mouse Buttons at Mouse press:" << m_context.m_mouseButtonsAtMousePress;
+
+      // qDebug() << "The current m_lastZ value:" << m_context.m_lastZ;
 
       deconvolute();
       computeResolvingPower();
@@ -179,6 +179,8 @@ MassSpecTracePlotWidget::mousePressHandler([[maybe_unused]] QMouseEvent *event)
 
   BasePlotWidget::mousePressHandler(event);
 
+  // qDebug() << "The current m_lastZ value:" << m_context.m_lastZ;
+
   emit mousePressEventSignal(m_context);
 
   // qDebug() << "Exiting after having emitted mousePressEventSignal with context:"
@@ -192,11 +194,22 @@ MassSpecTracePlotWidget::mouseReleaseHandler(QMouseEvent *event)
 {
   // qDebug() << "Entering";
 
- // Before working on the various data belonging to the base context, we need
- // to get it from the base class and refresh our local context with it.
- refreshBaseContext();
+  // Before working on the various data belonging to the base context, we need
+  // to get it from the base class and refresh our local context with it.
+  refreshBaseContext();
 
- BasePlotWidget::mouseReleaseHandler(event);
+  BasePlotWidget::mouseReleaseHandler(event);
+
+  // qDebug() << "The current m_lastZ value:" << m_context.m_lastZ;
+
+  if(!m_context.m_isMouseDragging)
+    {
+      // Since we were not dragging, by essence we were not measuring
+      // distances and _a fortiori_ we were not deconvoluting. So
+      // reset deconvolution data in the context.
+
+      m_context.resetDeconvolutionData();
+    }
 
   emit mouseReleaseEventSignal(m_context);
 
@@ -222,8 +235,16 @@ MassSpecTracePlotWidget::refreshBaseContext() const
   // qDebug().noquote() << "The base plot context:" <<
   // BasePlotWidget::m_context.toString();
 
+
+  // qDebug() << "Right before refreshing the context, the current m_lastZ value:"
+  //          << m_context.m_lastZ;
+
   m_context.initialize(BasePlotWidget::m_context);
 
+
+  // qDebug() << "Right after refreshing the context, the current m_lastZ value:"
+  //          << m_context.m_lastZ;
+
   // qDebug().noquote() << "After refreshing the base context, base context:"
   //                    << m_context.toString();
 
@@ -232,8 +253,7 @@ MassSpecTracePlotWidget::refreshBaseContext() const
 
 
 void
-MassSpecTracePlotWidget::setChargeMinimalFractionalPart(
-  double charge_fractional_part)
+MassSpecTracePlotWidget::setChargeMinimalFractionalPart(double charge_fractional_part)
 {
   m_chargeMinimalFractionalPart = charge_fractional_part;
 }
@@ -265,6 +285,8 @@ bool
 MassSpecTracePlotWidget::deconvolute()
 {
 
+  // qDebug() << "The current m_lastZ value:" << m_context.m_lastZ;
+
   // There are two situations: when the user is deconvoluting on the
   // basis of the distance between two consecutive peaks of a same
   // isotopic cluster or when the user deconvolutes on the basis of two
@@ -320,58 +342,41 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   // That parameter defaults to 1, that is the two peaks are immediately
   // consecutive, that is, there is only one interval.
 
-  // We use the m_contex.basecontext.m_xRegionRange structure that is unsorted.
-  // That is, lower is the start drag point.x and upper is the current drag
-  // point.x. If dragging occurs from left to right, start.x < cur.x.
-  // We use the unsorted values, because we need to know in which direction
-  // the user has drug the mouse, because we want to provide the Mr value
-  // for the peak currently under the mouse cursor, that is under
-  // currentDragPoint, that is the value in
-  // m_context.m_baseContext.m_xRegionRange.upper.
+  qDebug() << "The span is:" << span;
 
+  // The m_context ranges are inherently sorted. This is not something that
+  // is favorable to us because we need to know what is the direction of the
+  // drag. That should be configurable, but we can establish that by
+  // default, the z value will be calculated for the mass peak at which
+  // the mouse drag movement started.
+
+  // These two values reflect a m/z range:
+  // startMz and curMz are always sorted (startMz < curMz)
   double startMz = m_context.m_xRegionRangeStart;
   double curMz   = m_context.m_xRegionRangeEnd;
 
-  // qDebug() << "startMz:" << startMz << "curMz:" << curMz;
+  qDebug() << "startMz:" << startMz << "curMz:" << curMz;
 
   if(startMz == curMz)
     {
-      m_context.m_lastZ            = -1;
-      m_context.m_lastMz           = std::numeric_limits<double>::min();
-      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.m_lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = std::numeric_limits<quint16>::max();
+      m_context.m_lastMz           = qQNaN();
+      m_context.m_lastTicIntensity = qQNaN();
+      m_context.m_lastMr           = qQNaN();
 
+      qDebug() << "Start and Cur are the same, no deconvolution possible.";
       return false;
     }
 
-  // We need to be aware that the status bar of the window that contains
-  // this plot widget shows the cursor position realtime, and that cursor
-  // position is the m_currentDragPoint.x value, that is, curMz. Thus, we need
-  // to make the calculations with the charge being the one of the polymer under
-  // the cursor position. This is tricky because it changes when the user
-  // switches drag senses: from left to right and right to left.
-  // The way z is calculated always makes it the charge of the highest mz
-  // value. So knowing this, depending on the drag direction we'll have to take
-  // curMz and apply to it either z charge (left to right drag) or (z+span)
-  // charge (right to left).
+  // After much discussing, the agreement we reached with users is that the
+  // m/z value that is reported has to be that of the clicked peak, that is
+  // the start point of the mouse cursor drag operation. The z charge value
+  // has to be related to that m/z value.
 
-  // Make sure lower is actually lower, even if drag is from right to left.
-  // This is only to have a single charge calculation.
-  double lowerMz;
-  double upperMz;
-
-  if(startMz < curMz)
-    {
-      lowerMz = startMz;
-      upperMz = curMz;
-    }
-  else
-    {
-      lowerMz = curMz;
-      upperMz = startMz;
-    }
-
-  double chargeTemp = ((lowerMz * span) - span) / (upperMz - lowerMz);
+  double chargeTemp = ((startMz * span) - span) / (curMz - startMz);
+  // This is the charge of the least charged peak, that is, by necessity
+  // the charge of the peak on the right (curMz, because the values
+  // are sorted).
 
   // Make a judicious roundup.
 
@@ -393,22 +398,19 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   // m_chargeMinimalFractionalPart, then we consider that the peaks do not
   // belong to the same charge state envelope.
 
-  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-  //<< "Charge:" << chargeIntPart
-  //<< "Charge fractional part: " << chargeFracPart;
+  // qDebug() << "Charge:" << chargeIntPart << "Charge fractional part: " << chargeFracPart;
 
 
-  if(chargeFracPart >=
-       (1 - m_chargeMinimalFractionalPart /* that is >= 0.01 */) &&
+  if(chargeFracPart >= (1 - m_chargeMinimalFractionalPart /* that is >= 0.01 */) &&
      chargeFracPart <= m_chargeMinimalFractionalPart /* that is <= 0.99 */)
     {
-      m_context.m_lastZ            = -1;
-      m_context.m_lastMz           = std::numeric_limits<double>::min();
-      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.m_lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = std::numeric_limits<quint16>::max();
+      m_context.m_lastMz           = qQNaN();
+      m_context.m_lastTicIntensity = qQNaN();
+      m_context.m_lastMr           = qQNaN();
 
       // qDebug() << "Not a charge state family peak,"
-      //<< "returning from deconvoluteChargeState";
+      //          << "returning from deconvoluteChargeState";
 
       return false;
     }
@@ -418,33 +420,39 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   else
     m_context.m_lastZ = chargeIntPart;
 
-  // Now, to actually compute the molecular mass based on the charge and on
-  // the currently displayed m/z value, we need to have some thinking:
+  qDebug() << "Initially computed m_lastZ as " << m_context.m_lastZ;
 
-  if(startMz < curMz)
+  // We know the that formula above computed the charge of the least charged
+  // ion, that corresponds to the greater m/z value of the range: curMz.
+
+  // Now, if the user did click on that least-charged peak, nothing is
+  // to be modified. But, if the user did click on the most-charged
+  // peak, that is on startMz, the we need to fix the values:
+
+  if(static_cast<int>(m_context.m_dragDirections) & static_cast<int>(DragDirections::RIGHT_TO_LEFT))
     {
-      // The drag was from left to right, that is curMz is greater than
-      // startMz. Fine, the z value is effectively the charge of the ion at
-      // curMz. Easy, no charge value modification here.
+      qDebug() << "Dragging from right to left, that is from higher m/z value.";
+      m_context.m_lastMz = curMz;
     }
-  else
+  else if(static_cast<int>(m_context.m_dragDirections) &
+          static_cast<int>(DragDirections::LEFT_TO_RIGHT))
     {
-      // The drag was from right to left, that is curMz is less than startMz.
-      // So we want to show the charge of the curMz, that is, z + span.
-      m_context.m_lastZ = m_context.m_lastZ + span;
+      qDebug() << "Dragging from left to right, we need to report"
+               << "the mass for the left peak, that is for z+span and lower m/z value.";
+      m_context.m_lastZ += span;
+      m_context.m_lastMz = startMz;
     }
 
-  m_context.m_lastMz = curMz;
-  m_context.m_lastMr =
-    (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
+  qDebug() << "Final m_lastZ is " << m_context.m_lastZ << "m/z: m_context.m_lastMz";
 
-  // qDebug() << "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
-  //<< "m_lastMz (curMz):"
-  //<< QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
-  //<< "m_lastMass:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6)
-  //<< "m_lastZ:" << QString("%1").arg(m_context.m_lastZ);
+  m_context.m_lastMr = (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
-  // qDebug() << "returning true";
+  qDebug() << "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
+           << "curMz:" << QString("%1").arg(curMz, 0, 'f', 6)
+           << "m_lastMz (make computation for this startMz):"
+           << QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
+           << "m_lastZ:" << QString("%1").arg(m_context.m_lastZ)
+           << "m_lastMass:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6);
 
   // The m_context was refreshed with the base class context in the calling
   // chain.
@@ -472,37 +480,50 @@ bool
 MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
 {
 
-  if(m_context.m_xRegionRangeStart == m_context.m_xRegionRangeEnd)
+  double startMz = m_context.m_xRegionRangeStart;
+  double curMz   = m_context.m_xRegionRangeEnd;
+
+  qDebug() << "startMz:" << startMz << "curMz:" << curMz;
+
+  if(startMz == curMz)
     {
-      // qDebug() << __FILE__ << __LINE__
-      //<< "Same xRegionRange.upper and xRegionRange.lower:"
-      //<< "returning from deconvoluteIsotopicCluster";
+      m_context.m_lastZ            = std::numeric_limits<quint16>::max();
+      m_context.m_lastMz           = qQNaN();
+      m_context.m_lastTicIntensity = qQNaN();
+      m_context.m_lastMr           = qQNaN();
 
       return false;
     }
 
   double chargeTemp = 1 / fabs(m_context.m_xDelta);
 
+  qDebug() << qSetRealNumberPrecision(6) << "curMz - startMz = " << fabs(curMz - startMz)
+           << "while m_context.m_xDelta = " << m_context.m_xDelta;
+
+  // Sanity check
+  if(fabs(m_context.m_xDelta) != fabs(curMz - startMz))
+    qFatal() << "Programming error.";
+
   // Make a judicious roundup.
   double chargeIntPart;
   double chargeFracPart = modf(chargeTemp, &chargeIntPart);
 
-  // qDebug() << "m_xDelta:" << m_context.m_baseContext.m_xDelta
-  //<< "chargeTemp:" << QString("%1").arg(chargeTemp, 0, 'f', 6)
-  //<< "chargeIntPart:" << chargeIntPart
-  //<< "chargeFracPart:" << QString("%1").arg(chargeFracPart, 0, 'f', 6)
-  //<< "m_chargeMinimalFractionalPart:" << m_chargeMinimalFractionalPart;
+  // qDebug() << "m_xDelta:" << m_context.m_xDelta
+  //          << "chargeTemp:" << QString("%1").arg(chargeTemp, 0, 'f', 6)
+  //          << "chargeIntPart:" << chargeIntPart
+  //          << "chargeFracPart:" << QString("%1").arg(chargeFracPart, 0, 'f', 6)
+  //          << "m_chargeMinimalFractionalPart:" << m_chargeMinimalFractionalPart;
 
-  if(chargeFracPart >= (1 - m_chargeMinimalFractionalPart) &&
-     chargeFracPart <= m_chargeMinimalFractionalPart)
+  if(chargeFracPart >= (1 - m_chargeMinimalFractionalPart /* that is >= 0.01 */) &&
+     chargeFracPart <= m_chargeMinimalFractionalPart /* that is <= 0.99 */)
     {
-      m_context.m_lastZ            = -1;
-      m_context.m_lastMz           = std::numeric_limits<double>::min();
-      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.m_lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = std::numeric_limits<quint16>::max();
+      m_context.m_lastMz           = qQNaN();
+      m_context.m_lastTicIntensity = qQNaN();
+      m_context.m_lastMr           = qQNaN();
 
       // qDebug() << "Not in a isotopic cluster peak:"
-      //<< "returning from deconvoluteIsotopicCluster";
+      //          << "returning from deconvoluteIsotopicCluster";
 
       return false;
     }
@@ -524,6 +545,8 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
       //<< m_context.m_lastZ;
     }
 
+  // qDebug() << "Settled on m_lastZ: " << m_context.m_lastZ;
+
   // Now that we have the charge in the form of an int, we can compute the
   // Mr of the lightest isotopic cluster peak (the one that has the lowest x
   // value). That value is stored in m_xRangeLower.
@@ -531,14 +554,13 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
   // We need to sort the xRegionRange before being certain that lower is indeed
   // the left value of the drag span.
 
-  m_context.m_lastMz = std::min<double>(m_context.m_xRegionRangeStart,
-                                        m_context.m_xRegionRangeEnd);
+  m_context.m_lastMz = std::min<double>(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd);
 
-  m_context.m_lastMr =
-    (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
+  m_context.m_lastMr = (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
-  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-  //<< "returning true";
+  // qDebug() << "m_lastMz :" << QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
+  //          << "m_lastZ:" << QString("%1").arg(m_context.m_lastZ)
+  //          << "m_lastMr:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6);
 
   // The m_context was refreshed with the base class context in the calling
   // chain.
@@ -571,8 +593,7 @@ MassSpecTracePlotWidget::computeResolvingPower()
   //<< "m_context.m_xDelta / 2: " << m_context.m_xDelta / 2;
 
   m_context.m_lastResolvingPower =
-    (std::min<double>(m_context.m_xRegionRangeStart,
-                      m_context.m_xRegionRangeEnd) +
+    (std::min<double>(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd) +
      (m_context.m_xDelta / 2)) /
     m_context.m_xDelta;
 
