@@ -130,6 +130,13 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
     REQUIRE(pterm.m_diffFormula.toStdString() == "H(12) C(4) 13C(3) N 15N O");
     REQUIRE(formula.getMass() == Catch::Approx(144.1020624229));
     REQUIRE(formula.getMass() == Catch::Approx(pterm.m_diffMono));
+
+
+    // USER:2-Ethynylbenzaldehyde
+    pappso::AaModificationP modpuser = AaModification::getInstance("USER:2-Ethynylbenzaldehyde");
+    REQUIRE(modpuser->getAccession().toStdString() == "USER:2-Ethynylbenzaldehyde");
+    
+    REQUIRE(modpuser->getMass() == Catch::Approx(112.03130012896400558));
   }
 
   SECTION("..:: test PSI-MOD removal ::..", "[Aa]")
@@ -339,4 +346,3 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
   return 0;
   */
 }
-
