@@ -297,8 +297,8 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     // QApplication app(QString(), QString());
     int argc(0);
-    char *argv[]          = {};
-    QCoreApplication *app = new QCoreApplication(argc, argv);
+    char *argv[]                           = {};
+    QCoreApplication *app [[maybe_unused]] = new QCoreApplication(argc, argv);
 
     pappso::MsFileAccessor accessor(
       "/gorgone/pappso/versions_logiciels_pappso/bruker/"
